#
# spec file for package perl-JSON-Parse
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name JSON-Parse
Name:           perl-JSON-Parse
Version:        0.62
Release:        bp156.2.4
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Parse JSON
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/B/BK/BKB/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
A module for parsing JSON. (JSON means "JavaScript Object Notation" and it
is specified in RFC 8259.)

JSON::Parse offers the function parse_json, which takes a string containing
JSON, and returns an equivalent Perl structure. It also offers validation
of JSON via valid_json, which returns true or false depending on whether
the JSON is correct or not, and assert_valid_json, which produces a
descriptive fatal error if the JSON is invalid. A function read_json reads
JSON from a file, and there is a safer version of parse_json called
parse_json_safe which doesn't throw exceptions.

For special cases of parsing, there are also methods new and parse, which
create a JSON parsing object and run it on text. See METHODS.

JSON::Parse accepts only UTF-8 as input. See UTF-8 only and Handling of
Unicode.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644
# MANUAL BEGIN
for file in $(find . -type f); do
    sed -i "s|/home/ben/software/install/bin/perl|%{_bindir}/perl|g; \
            s|/home/ben/projects/Json3/blib/lib|%{perl_vendorarch}|g; \
            s|use lib '/home/ben/projects/Json3/blib/arch';||g;" "$file"
done
# hunspell=`pkg-config --libs hunspell | sed -e 's,-l,,; s,  *,,g'`
# MANUAL END

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md examples README

%changelog
* Sat Jul 16 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.62
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.62 2022-07-16
  * Bug fix for tokenize with backslash-double quote
* Thu Feb 11 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.61
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.61 2021-02-11
  * Add upgrade_utf8 method
* Tue Jan 26 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.60
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
* Mon Jan  4 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.59
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.59 2021-01-04
  * "json_file_to_perl" renamed "read_json"
  * Documentation work
  - - Benchmarks section updated with latest versions, add Cpanel::JSON::XS
  - - Add Metacpan vote ratings to other CPAN modules section
  - - Sections reordered to put methods above parsing details
  0.58 2021-01-01
  * Protect against stack overflows by having maximum parsing depth
  - - set_max_depth, get_max_depth methods added
  * Documentation updated
  - - JSON RFC changed to 8259
  - - Discussion of Unicode tests in JSON Test Suite
* Fri Jul 10 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.57
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.57 2020-07-09
  * Bug fix for long strings
* Tue Feb 18 2020 <timueller+perl@suse.de>
- updated to 0.56
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.56 2020-02-06
  * Allow build on Solaris and SunOS
  0.55_02 2019-01-24
  * For testing of Daxim segfault through CPAN testers
* Thu Nov  9 2017 coolo@suse.com
- updated to 0.55
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.55 2017-10-21
  * Versions synchronised
  * Memory problem on Cygwin addressed
  0.54 2017-10-20
  * Refuse to support Solaris
* Thu Oct 19 2017 coolo@suse.com
- updated to 0.53
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.53 2017-10-18
  * Windows build fix
  0.52 2017-10-18
  * Removed unnecessary test
  0.50 2017-10-18
  * tokenize_text method added to JSON::Tokenize
* Thu Jul 20 2017 lars@linux-schulserver.de
- do not use local perl and libs: use system binaries and libs instead
* Sun Nov 27 2016 coolo@suse.com
- updated to 0.49
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.49 2016-11-26
  * Behaviour for undefined, whitespace-only inputs was altered
  * JSON Parsing Test Suite compliance
* Mon Nov 21 2016 coolo@suse.com
- updated to 0.48
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.48 2016-11-20
  * Add "check" method for the benefit of JSON::Repair
* Fri Nov 18 2016 coolo@suse.com
- updated to 0.47
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.47 2016-11-16
  * Bug fixes for Perl 12 and earlier regarding diagnostics_hash method
  0.46 2016-11-16
  * Remove experimental feature $json_diagnostics
  * Add diagnostics_hash method as a replacement for $json_diagnostics
  * Better warnings for parse_json_safe
  * Add the examples directory files to the CPAN distribution
  * Documentation rewrites
  0.45 2016-11-15
  * Remove non-functioning JSON::Whitespace module from CPAN distribution
* Mon Nov 14 2016 coolo@suse.com
- updated to 0.44
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.44 2016-11-13
  * Add a primitive interface to JSON::Tokenize
  * Document the JSON::Tokenize interface
* Sun Nov  6 2016 coolo@suse.com
- updated to 0.43
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.43 2016-11-05
  * Remove validjson dependence on Path::Tiny.
  * Produce better outputs from validjson script
* Tue Aug 23 2016 coolo@suse.com
- updated to 0.42
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.42 2016-08-22
  * Long string copying bug fixed.
* Thu Jun 23 2016 coolo@suse.com
- updated to 0.41
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.41 2016-06-14
  * Implement "warn_only"
  * Documentation clarifications
* Mon May 23 2016 coolo@suse.com
- updated to 0.40
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.40 2016-05-22
  * Compilation warning, possible memory leaks (SHLOMIF)
* Fri Nov 20 2015 coolo@suse.com
- updated to 0.39
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.39 2015-11-18
  * Fix for 64 bit
  * Changed error message documentation to machine-readable
* Sun Nov  8 2015 coolo@suse.com
- updated to 0.38
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.38 2015-10-30
  * Add object interface for more flexible parsing.
  * Add "parse_json_safe" with no exceptions and hash collision detection.
  * Add choice to copy literals.
  * Better documentation of changes and examples
* Sat Oct 31 2015 coolo@suse.com
- updated to 0.37
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.37 2015-10-29
  * Remove $JSON::Parse::true and false, use &PL_sv_yes and &PL_sv_no instead.
* Sat Oct 24 2015 coolo@suse.com
- updated to 0.36
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.36 2015-10-24
  * Document and install "validjson" script.
  * Document the "$JSON::Parse::json_diagnostics" global variable.
  0.35 2015-10-19
  * Minor documentation changes
  0.34 2015-10-19
  * Document key collisions
  * Extend SEE ALSO section on other JSON modules on CPAN.
* Mon Oct 12 2015 coolo@suse.com
- updated to 0.33
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.33 2015-10-09
  * Memory leak plug
  * Small speed improvements
  * Minor bug about commas after bare values
  * Documentation rewritten to clarify changes in 0.32 and testing.
* Sat Aug  1 2015 coolo@suse.com
- updated to 0.32
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
  0.32 2015-07-29
  * Update to accept bare values, per RFC 7159.
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.31
  see /usr/share/doc/packages/perl-JSON-Parse/Changes
* Fri Aug 26 2011 chris@computersalat.de
- cpanspec
- fix build for CentOS, SLE_10, SLE_11
- fix deps
  +  perl(Test::More) >= 0.88
* Fri Jun 10 2011 pascal.bleser@opensuse.org
- initial version (0.07)
